summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorToshi MARUYAMA <marutosijp2@yahoo.co.jp>2014-04-07 08:06:14 +0000
committerToshi MARUYAMA <marutosijp2@yahoo.co.jp>2014-04-07 08:06:14 +0000
commit6067bfcd0974d505951e02e6939a24d3ef3df7c6 (patch)
treea4ffcd39b12cf0aef1a3d5b888aa76803437f5e5 /lib
parent242b440073ced8d7cc2ff4706cda2e88b59e2b6f (diff)
downloadredmine-6067bfcd0974d505951e02e6939a24d3ef3df7c6.tar.gz
redmine-6067bfcd0974d505951e02e6939a24d3ef3df7c6.zip
fix typos of source comments at lib/redmine/wiki_formatting.rb
git-svn-id: http://svn.redmine.org/redmine/trunk@13070 e93f8b46-1217-0410-a6f0-8f06a7374b81
Diffstat (limited to 'lib')
-rw-r--r--lib/redmine/wiki_formatting.rb14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/redmine/wiki_formatting.rb b/lib/redmine/wiki_formatting.rb
index 3bf483da0..284cdc933 100644
--- a/lib/redmine/wiki_formatting.rb
+++ b/lib/redmine/wiki_formatting.rb
@@ -111,20 +111,20 @@ module Redmine
(?=<|\s|$)
}x unless const_defined?(:AUTO_LINK_RE)
- # Destructively remplaces urls into clickable links
+ # Destructively replaces urls into clickable links
def auto_link!(text)
text.gsub!(AUTO_LINK_RE) do
all, leading, proto, url, post = $&, $1, $2, $3, $6
if leading =~ /<a\s/i || leading =~ /![<>=]?/
- # don't replace URL's that are already linked
- # and URL's prefixed with ! !> !< != (textile images)
+ # don't replace URLs that are already linked
+ # and URLs prefixed with ! !> !< != (textile images)
all
else
# Idea below : an URL with unbalanced parethesis and
# ending by ')' is put into external parenthesis
if ( url[-1]==?) and ((url.count("(") - url.count(")")) < 0 ) )
- url=url[0..-2] # discard closing parenth from url
- post = ")"+post # add closing parenth to post
+ url=url[0..-2] # discard closing parenthesis from url
+ post = ")"+post # add closing parenthesis to post
end
content = proto + url
href = "#{proto=="www."?"http://www.":proto}#{url}"
@@ -133,7 +133,7 @@ module Redmine
end
end
- # Destructively remplaces email addresses into clickable links
+ # Destructively replaces email addresses into clickable links
def auto_mailto!(text)
text.gsub!(/([\w\.!#\$%\-+.]+@[A-Za-z0-9\-]+(\.[A-Za-z0-9\-]+)+)/) do
mail = $1
@@ -111,20 +111,20 @@ module Redmine
all
else
- # Idea below : an URL with unbalanced parethesis and
+ # Idea below : an URL with unbalanced parenthesis and
# ending by ')' is put into external parenthesis
if ( url[-1]==?) and ((url.count("(") - url.count(")")) < 0 ) )